@@ -29,34 +29,39 @@ if(! all(c(2012,12) ==   end(z))) stop('monthly test 2 end date error.')
 # quarterly national accounts
 #CARSA: national currency, nominal, SAAR (level)
 
-if (FALSE) { # failing with  "Premature end of file."  Dec 11, 2015
+  # failing with  "Premature end of file."  Dec 11, 2015
+  #  Sept 2015 QNA.CAN.GDP.CARSA.Q gave  500, message: Internal Server Error
+  #     This was a provider error now fixed,  BUG #80 closed
+  # But, in spring/summer 2016 it was valid query but returned no data.
+  # Also  'QNA.CAN.GDP.CARSA.Q'   was valid query but returned no data.
+  # 'QNA.CAN.B1_GE.CARSA.Q' does have data
 
-z <- TSget('QNA.CAN.PPPGDP.CARSA.Q', oecd)
+z <- TSget('QNA.CAN.B1_GE.CARSA.Q', oecd)
 if(! all(c(1960,1) == start(z))) stop('quarterly test 1 start date is changed.')
 if(4 != frequency(z)) stop('quarterly test 1 frequency error.')
 
-z <- TSget('QNA.CAN.PPPGDP.CARSA.Q', start=c(1990,2), end =c(2012,4), oecd)
+z <- TSget('QNA.CAN.B1_GE.CARSA.Q', start=c(1990,2), end =c(2012,4), oecd)
 if(! all(c(1990,2) == start(z))) stop('quarterly test 2 start date error.')
 if(! all(c(2012,4) ==   end(z))) stop('quarterly test 2 end date error.')
 
 #   test "+" and "|" in query and test setting names
-z <- TSget('QNA.CAN+USA|MEX.PPPGDP.CARSA.Q', 
+z <- TSget('QNA.CAN+USA|MEX.B1_GE.CARSA.Q', 
          names=c("Canada", "United States", "Mexico"),   oecd)
 
 # SDMX + and | queries do not determine the return order, TSget fixes by
 # reordering data. (Above query  was not returned in order in Dec 2014.)
-# The PPPGDP numbers are all relative to the US so USA numbers are 1.0 and next
-#  test checks that as a confirmation that re-order was done. 
 # This was BUG #22 which was closed with work around in RJSDMX by using ; to
 #  separate queries and maintain order.
-
-if(max(abs(1 - z[,2])) > 1e-16)
-          stop('quarterly test reorder series to apply names not working.')
+# No longer using PPPGDP but
+# The PPPGDP numbers are all relative to the US so USA numbers are 1.0 and next
+#  test checks that as a confirmation that re-order was done. 
+#if(max(abs(1 - z[,2])) > 1e-16)
+#          stop('quarterly test reorder series to apply names not working.')
 
 if(! all(c("Canada", "United States", "Mexico") == tframe::seriesNames(z)))
           stop('quarterly test setting series names not working.')
 
-if(! all(c(1955,1) == start(z))) 
+if(! all(c(1947,1) == start(z))) 
           stop('quarterly mulivariate test start date is changed.')
 
 if(4 != frequency(z)) 
@@ -66,8 +71,6 @@ if(4 != frequency(z))
 # tfplot::tfOnePlot(z, start=c(1990,1))
 
 
-} # end if (FALSE)
-
 # Annual only ??
 z <- TSget('BSI.NAT.EQU.TOT.DIR.CAN', oecd)  
 if(! all(c(2009,1) == start(z))) stop('annual test 0 start date is changed.')
